@@ -49,7 +49,6 @@
 #endif
 
 #include "bacon-video-widget.h"
-#include "bacon-video-widget-properties.h"
 #include "totem-statusbar.h"
 #include "totem-time-label.h"
 #include "totem-session.h"
@@ -906,18 +905,6 @@ totem_get_nice_name_for_stream (Totem *totem)
 	return retval;
 }
 
-static void
-update_skip_to (Totem *totem, gint64 time)
-{
-	if (time == totem->last_length)
-		return;
-
-	totem->last_length = time;
-
-	if (totem->skipto != NULL)
-		totem_skipto_update_range (totem->skipto, time);
-}
-
 static void
 update_mrl_label (Totem *totem, const char *name)
 {
@@ -934,7 +921,7 @@ update_mrl_label (Totem *totem, const char *name)
 		totem_statusbar_set_time_and_length (TOTEM_STATUSBAR
 				(totem->statusbar), 0, time / 1000);
 
-		update_skip_to (totem, time);
+		g_object_notify (G_OBJECT (totem), "stream-length");
 
 		/* Update the mrl label */
 		escaped = g_markup_escape_text (name, strlen (name));
@@ -955,7 +942,7 @@ update_mrl_label (Totem *totem, const char *name)
 		totem_statusbar_set_text (TOTEM_STATUSBAR (totem->statusbar),
 				_("Stopped"));
 
-		update_skip_to (totem, 0);
+		g_object_notify (G_OBJECT (totem), "stream-length");
 
 		/* Update the mrl label */
 		text = g_strdup_printf
@@ -982,13 +969,10 @@ totem_action_set_mrl_with_warning (Totem *totem, const char *mrl,
 		g_free (totem->mrl);
 		totem->mrl = NULL;
 		bacon_video_widget_close (totem->bvw);
+		totem_file_closed (totem);
 		play_pause_set_label (totem, TOTEM_PLAYLIST_STATUS_NONE);
 	}
 
-	/* Reset the properties and wait for the signal*/
-	bacon_video_widget_properties_reset
-		(BACON_VIDEO_WIDGET_PROPERTIES (totem->properties));
-
 	if (mrl == NULL)
 	{
 		retval = FALSE;
@@ -1018,8 +1002,6 @@ totem_action_set_mrl_with_warning (Totem *totem, const char *mrl,
 
 		/* Set the logo */
 		bacon_video_widget_set_logo_mode (totem->bvw, TRUE);
-		gtk_widget_set_sensitive (GTK_WIDGET (totem->properties),
-				FALSE);
 		update_mrl_label (totem, NULL);
 	} else {
 		gboolean caps;
@@ -1052,9 +1034,6 @@ totem_action_set_mrl_with_warning (Totem *totem, const char *mrl,
 		/* Clear the playlist */
 		totem_action_set_sensitivity ("clear-playlist", retval);
 
-		gtk_widget_set_sensitive
-			(GTK_WIDGET (totem->properties), retval);
-
 		/* Set the playlist */
 		play_pause_set_label (totem, retval ? STATE_PAUSED : STATE_STOPPED);
 
@@ -1081,6 +1060,8 @@ totem_action_set_mrl_with_warning (Totem *totem, const char *mrl,
 			g_free (totem->mrl);
 			totem->mrl = NULL;
 			bacon_video_widget_set_logo_mode (totem->bvw, TRUE);
+		} else {
+			totem_file_opened (totem, totem->mrl);
 		}
 	}
 	update_buttons (totem);
@@ -1171,7 +1152,34 @@ totem_action_seek_relative (Totem *totem, int off_sec)
 		char *msg, *disp;
 
 		disp = totem_uri_escape_for_display (totem->mrl);
-		msg = g_strdup_printf(_("Totem could not play '%s'."), totem->mrl);
+		msg = g_strdup_printf(_("Totem could not play '%s'."), disp);
+		g_free (disp);
+
+		totem_action_stop (totem);
+		totem_action_error (msg, err->message, totem);
+		g_free (msg);
+		g_error_free (err);
+	}
+}
+
+void
+totem_action_seek_time (Totem *totem, gint64 sec)
+{
+	GError *err = NULL;
+
+	if (totem->mrl == NULL)
+		return;
+	if (bacon_video_widget_is_seekable (totem->bvw) == FALSE)
+		return;
+
+	bacon_video_widget_seek_time (totem->bvw, sec, &err);
+
+	if (err != NULL)
+	{
+		char *msg, *disp;
+
+		disp = totem_uri_escape_for_display (totem->mrl);
+		msg = g_strdup_printf(_("Totem could not play '%s'."), disp);
 		g_free (disp);
 
 		totem_action_stop (totem);
@@ -1454,8 +1462,10 @@ on_got_redirect (BaconVideoWidget *bvw, const char *mrl, Totem *totem)
 	g_free (old_mrl);
 
 	bacon_video_widget_close (totem->bvw);
+	totem_file_closed (totem);
 	totem_gdk_window_set_waiting_cursor (totem->win->window);
 	bacon_video_widget_open (totem->bvw, new_mrl, NULL);
+	totem_file_opened (totem, new_mrl);
 	gdk_window_set_cursor (totem->win->window, NULL);
 	bacon_video_widget_play (bvw, NULL);
 	g_free (new_mrl);
@@ -1481,9 +1491,7 @@ on_channels_change_event (BaconVideoWidget *bvw, Totem *totem)
 	/* updated stream info (new song) */
 	name = totem_get_nice_name_for_stream (totem);
 
-	bacon_video_widget_properties_update
-		(BACON_VIDEO_WIDGET_PROPERTIES (totem->properties),
-		 totem->bvw);
+	totem_metadata_updated (totem, NULL, NULL, NULL);
 
 	if (name != NULL) {
 		update_mrl_label (totem, name);
@@ -1507,9 +1515,7 @@ on_playlist_change_name (TotemPlaylist *playlist, Totem *totem)
 
 	if (totem_playlist_get_current_metadata (playlist, &artist,
 						 &title, &album) != FALSE) {
-		bacon_video_widget_properties_from_metadata (
-			BACON_VIDEO_WIDGET_PROPERTIES (totem->properties),
-			artist, title, album);
+		totem_metadata_updated (totem, artist, title, album);
 
 		g_free (artist);
 		g_free (album);
@@ -1522,9 +1528,7 @@ on_got_metadata_event (BaconVideoWidget *bvw, Totem *totem)
 {
         char *name = NULL;
 
-	bacon_video_widget_properties_update
-		(BACON_VIDEO_WIDGET_PROPERTIES (totem->properties),
-		 totem->bvw);
+	totem_metadata_updated (totem, NULL, NULL, NULL);
 
 	name = totem_get_nice_name_for_stream (totem);
 
@@ -1578,9 +1582,8 @@ update_seekable (Totem *totem)
 
 	totem_action_set_sensitivity ("skip-forward", seekable);
 	totem_action_set_sensitivity ("skip-backwards", seekable);
-	totem_action_set_sensitivity ("skip-to", seekable);
-	if (totem->skipto)
-		totem_skipto_set_seekable (totem->skipto, seekable);
+
+	g_object_notify (G_OBJECT (totem), "seekable");
 }
 
 static void
@@ -1590,8 +1593,6 @@ update_current_time (BaconVideoWidget *bvw,
 		float current_position,
 		gboolean seekable, Totem *totem)
 {
-	update_skip_to (totem, stream_length);
-
 	if (totem->seek_lock == FALSE)
 	{
 		gtk_adjustment_set_value (totem->seekadj,
@@ -1614,9 +1615,11 @@ update_current_time (BaconVideoWidget *bvw,
 		totem_time_label_set_time
 			(TOTEM_TIME_LABEL (totem->tcw_time_label),
 			 current_time, stream_length);
-		bacon_video_widget_properties_from_time
-			(BACON_VIDEO_WIDGET_PROPERTIES (totem->properties),
-			 stream_length);
+	}
+
+	if (totem->stream_length != stream_length) {
+		g_object_notify (G_OBJECT (totem), "stream-length");
+		totem->stream_length = stream_length;
 	}
 }
 
@@ -1834,6 +1837,7 @@ totem_action_open_files_list (Totem *totem, GSList *list)
 					 playlist_changed_cb, totem);
 				changed = totem_playlist_clear (totem->playlist);
 				bacon_video_widget_close (totem->bvw);
+				totem_file_closed (totem);
 				cleared = TRUE;
 			}
 
@@ -1869,71 +1873,6 @@ totem_action_open_files_list (Totem *totem, GSList *list)
 	return changed;
 }
 
-static void
-commit_hide_skip_to (GtkDialog *dialog, gint response, Totem *totem)
-{
-	GError *err = NULL;
-
-	if (response != GTK_RESPONSE_OK)
-	{
-		gtk_widget_destroy (GTK_WIDGET (totem->skipto));
-		return;
-	}
-
-	gtk_widget_hide (GTK_WIDGET (dialog));
-
-	bacon_video_widget_seek_time (totem->bvw,
-			totem_skipto_get_range (totem->skipto), &err);
-
-	gtk_widget_destroy (GTK_WIDGET (totem->skipto));
-
-	if (err != NULL)
-	{
-		char *msg, *disp;
-
-		disp = totem_uri_escape_for_display (totem->mrl);
-		msg = g_strdup_printf(_("Totem could not seek in '%s'."), disp);
-		g_free (disp);
-		totem_action_stop (totem);
-		totem_action_error (msg, err->message, totem);
-		g_free (msg);
-		g_error_free (err);
-	}
-}
-
-void
-totem_action_skip_to (Totem *totem)
-{
-	char *filename;
-	TotemSkipto **skipto;
-
-	if (totem->seekable == FALSE)
-		return;
-
-	if (totem->skipto != NULL) {
-		gtk_window_present (GTK_WINDOW (totem->skipto));
-		return;
-	}
-
-	filename = totem_interface_get_full_path ("skip_to.glade");
-	totem->skipto = TOTEM_SKIPTO (totem_skipto_new (filename));
-	g_free (filename);
-	totem_skipto_update_range (totem->skipto, totem->last_length);
-
-	g_signal_connect (G_OBJECT (totem->skipto), "delete-event",
-			G_CALLBACK (gtk_widget_destroy), NULL);
-	g_signal_connect (G_OBJECT (totem->skipto), "response",
-			G_CALLBACK (commit_hide_skip_to), totem);
-
-	skipto = &totem->skipto;
-	g_object_add_weak_pointer (G_OBJECT (totem->skipto),
-				   (gpointer *) skipto);
-
-	gtk_window_set_transient_for (GTK_WINDOW (totem->skipto),
-			GTK_WINDOW (totem->win));
-	gtk_widget_show (GTK_WIDGET (totem->skipto));
-}
-
 static void
 on_fs_exit1_activate (GtkButton *button, Totem *totem)
 {
@@ -2320,18 +2259,33 @@ update_fullscreen_size (Totem *totem)
 gboolean
 totem_is_fullscreen (Totem *totem)
 {
+	g_return_val_if_fail (TOTEM_IS_OBJECT (totem), FALSE);
+
 	return (totem->controls_visibility == TOTEM_CONTROLS_FULLSCREEN);
 }
 
 gboolean
 totem_is_playing (Totem *totem)
 {
+	g_return_val_if_fail (TOTEM_IS_OBJECT (totem), FALSE);
+
 	if (totem->bvw == NULL)
 		return FALSE;
 
 	return bacon_video_widget_is_playing (totem->bvw) != FALSE;
 }
 
+gboolean
+totem_is_seekable (Totem *totem)
+{
+	g_return_val_if_fail (TOTEM_IS_OBJECT (totem), FALSE);
+
+	if (totem->bvw == NULL)
+		return FALSE;
+
+	return bacon_video_widget_is_seekable (totem->bvw) != FALSE;
+}
+
 static void
 move_popups (Totem *totem)
 {
@@ -2671,7 +2625,7 @@ totem_action_handle_key_press (Totem *totem, GdkEventKey *event)
 		if (event->state & GDK_CONTROL_MASK) {
 			totem_action_take_screenshot (totem);
 		} else {
-			totem_action_skip_to (totem);
+			return FALSE;
 		}
 		break;
 	case GDK_t:
@@ -3235,7 +3189,6 @@ totem_callback_connect (Totem *totem)
 	totem_action_set_sensitivity ("previous-chapter", FALSE);
 	totem_action_set_sensitivity ("skip-forward", FALSE);
 	totem_action_set_sensitivity ("skip-backwards", FALSE);
-	totem_action_set_sensitivity ("skip-to", FALSE);
 }
 
 static void
@@ -3510,7 +3463,6 @@ main (int argc, char **argv)
 
 	/* The sidebar */
 	playlist_widget_setup (totem);
-	totem->properties = bacon_video_widget_properties_new ();
 
 	/* The rest of the widgets */
 	totem->state = STATE_STOPPED;
